GithubService class

Service to interact with GitHub API and fetch pinned repositories

Constructors

GithubService({Client? client, String? accessToken})

Properties

accessToken String?
Optional GitHub personal access token for authenticated requests
final
client → Client
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchPinnedRepositories(String username) Future<List<Repository>>
Fetches pinned repositories for a GitHub username using GraphQL API
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited