Repository class

Represents a GitHub repository with essential information

Constructors

Repository({required String name, required String description, required int stars, required String language, required String avatarUrl, required String url})
Repository.fromGraphQLJson(Map<String, dynamic> json)
Creates a Repository from GraphQL API response
factory

Properties

avatarUrl String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
language String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stars int
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited