Repository class

Constructors

Repository({required String name, required String description, required int stars, required String language, required String avatarUrl, required bool isPinned})
Repository.fromJson(Map<String, dynamic> json)
factory

Properties

avatarUrl String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
isPinned bool
final
language String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stars int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited